@@ -5,12 +5,8 @@ from LuluTest.page_element_interface.IPageElement import load_driver
 
 
 class Action(PageActionsDecorator, ElementActions):
-    def __init__(self, driver_type=None, options=None):
-        if driver_type is None:
-            driver_type = 'Chrome'
-        if options is None:
-            options = ['headless']
-        self.driver = load_driver(driver_type, options)
+    def __init__(self, browser_options=None):
+        self.driver = load_driver(browser_options)
         self.action_map = None
         PageActionsDecorator.__init__(self, PageActions(self.driver))
         ElementActions.__init__(self, self.driver)
