@@ -3,9 +3,4 @@ from .alert_element import AlertElement
 from .page_element import PageElement
 from .locator import Locator
 
-__all__ = [
-    'alert_element',
-    'base_element',
-    'locator',
-    'page_element'
-]
+__all__ = ["alert_element", "base_element", "locator", "page_element"]
