@@ -1,6 +1,5 @@
-
 class BaseElement:
-    def __init__(self, name=''):
+    def __init__(self, name=""):
         self.name = name
         self.active = False
         self.is_page_element = False
