@@ -2,9 +2,4 @@ from .step import Step
 from .steps import Steps
 from .do import Do, DoStep
 
-__all__ = [
-    'Do',
-    'Step',
-    'Steps',
-    'DoStep'
-]
+__all__ = ["Do", "Step", "Steps", "DoStep"]
